@@ -2,10 +2,13 @@
 notifications helper
 """
 
+# Django
 from django.contrib.auth.models import User
 
+# Alliance Auth
 from allianceauth.notifications import notify
 
+# AA SRP
 from aasrp.app_settings import aa_discordnotify_active, allianceauth_discordbot_active
 
 
@@ -20,21 +23,15 @@ def send_user_notification(user: User, level: str, title: str, message: str) ->
     :param message:
     """
 
-    notify(
-        user=user,
-        title=title,
-        level=level,
-        message=message,
-    )
+    notify(user=user, title=title, level=level, message=message)
 
     # send a PM to the user on Discord if allianceauth-discordbot
     # is active and not aa-discordnotify
     if allianceauth_discordbot_active() and not aa_discordnotify_active():
+        # Third Party
         import aadiscordbot.tasks
 
-        aadiscordbot.tasks.send_direct_message_by_user_id.delay(
-            user_pk=user.pk, message_content=message
-        )
+        aadiscordbot.tasks.send_direct_message_by_user_id.delay(user.pk, message)
 
 
 def send_message_to_discord_channel(
@@ -49,6 +46,7 @@ def send_message_to_discord_channel(
     """
 
     if allianceauth_discordbot_active():
+        # Third Party
         import aadiscordbot.tasks
 
         aadiscordbot.tasks.send_channel_message_by_discord_id.delay(
